pub struct TokenProviderChain { /* private fields */ }Expand description
Access token provider that checks a series of inner providers.
Each provider will be evaluated in order:
- If a provider returns valid
Tokenthey will be returned immediately. No other token providers will be used. - Otherwise, if a provider returns
TokenError::TokenNotLoaded, the next provider will be checked. - Finally, if a provider returns any other error condition, an error will be returned immediately.
Examples
use aws_config::meta::token::TokenProviderChain;
use aws_config::profile::ProfileFileTokenProvider;
use aws_credential_types::Token;
let provider = TokenProviderChain::first_try("Profile", ProfileFileTokenProvider::builder().build())
.or_else("Static", Token::new("example", None));Implementations
Sourceimpl TokenProviderChain
impl TokenProviderChain
Sourcepub fn first_try(
name: impl Into<Cow<'static, str>>,
provider: impl ProvideToken + 'static,
) -> Self
pub fn first_try( name: impl Into<Cow<'static, str>>, provider: impl ProvideToken + 'static, ) -> Self
Create a TokenProviderChain that begins by evaluating this provider
Sourcepub fn or_else(
self,
name: impl Into<Cow<'static, str>>,
provider: impl ProvideToken + 'static,
) -> Self
pub fn or_else( self, name: impl Into<Cow<'static, str>>, provider: impl ProvideToken + 'static, ) -> Self
Add a fallback provider to the token provider chain
Sourcepub async fn or_default_provider(self) -> Self
Available on crate feature sso only.
pub async fn or_default_provider(self) -> Self
sso only.Add a fallback to the default provider chain
Sourcepub async fn default_provider() -> Self
Available on crate feature sso only.
pub async fn default_provider() -> Self
sso only.Creates a token provider chain that starts with the default provider