pub struct FrameworkMetadata { /* private fields */ }Expand description
Metadata about a software framework or third-party library that is being used with the SDK.
This is rendered into the user agent string (as lib/{name}/{version}) so that third-party
libraries built on top of the AWS SDK can self-identify in requests they make.
The name and version may only have alphanumeric characters and any of these characters:
!#$%&'*+-.^_`|~Spaces are not allowed.
Implementations
Sourceimpl FrameworkMetadata
impl FrameworkMetadata
Sourcepub fn new(
name: impl Into<Cow<'static, str>>,
version: Option<impl Into<Cow<'static, str>>>,
) -> Result<FrameworkMetadata, InvalidFrameworkMetadata>
pub fn new( name: impl Into<Cow<'static, str>>, version: Option<impl Into<Cow<'static, str>>>, ) -> Result<FrameworkMetadata, InvalidFrameworkMetadata>
Creates new FrameworkMetadata.
This will return an InvalidFrameworkMetadata error if the given name or version doesn’t
meet the character requirements. See FrameworkMetadata for details on these requirements.